@@ -1,5 +1,5 @@
 #
-# Django Code Deploy
+# dcCodeDeploy
 #
 # Copyright 2015 - 2021 devops.center llc
 #
@@ -289,7 +289,7 @@ def _log_hosts(instances):
 
 
 @task
-def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', angularPostBuild='', installPath='.', node=''):
+def build(branch='', ngBuild='', ngApp='', angularBuild='', angularEnv='', angularPostBuild='', installPath='.', node=''):
 
 
  # Need to give each build job it's own yarn cache, as the yarn cache is not safe for concurrent builds.
@@ -302,7 +302,10 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', angularP
     # ensure yarn installs all build tools
         local("pwd")
         local('yarn --production=false --no-progress --non-interactive')
- 
+
+# ngBuild works for both app and angular builds. 
+# If angularEnv is specified, then yarn is called with `--configuration=<angularEnv>`, suitable for angular builds.
+# Otherwise call without, so suitable for app builds.
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
             local('yarn build %s %s' % (options, ngApp))
@@ -310,6 +313,8 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', angularP
             local('cp -R migrations/ dist')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
 
+#
+# deprecated, as `ngBuild` now handles both app and angular builds are handled in `ngBuild`.
         elif angularBuild:
             config = angularEnv if angularEnv else ENVIRONMENT
             local('yarn build --configuration=%s %s' % (config, ngApp))
@@ -317,6 +322,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', angularP
                 local('%s %s' % (angularPostBuild, ngApp))
             local('cp -r public/* dist/')
 
+# this is for the legacy, non-angular app builds
         elif node:
             local('npm run dist')
             local('if [[ -d "config" ]]; then echo "<collecting config>" ; rsync -ra --stats config/ dist/config; fi;')
@@ -324,13 +330,6 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', angularP
 
         local('du -hd1 %s' % yarn_cache)
 
-    # make sure the new files are part of the local git repo
-    #local('find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
-    #local('echo "%s.tar.*" >> .gitignore' % TAR_NAME)
-    #local('echo "fabfile.*" >> .gitignore')
-    #local("git add .")
-    #local("git commit -am 'add results of build' --no-verify --quiet")
-
 
 @task
 def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildWorker="True", buildScheduler="False"):
@@ -399,11 +398,14 @@ def set_git_sha():
     local('git add .')
 
 
+
+# Use either git or tar to create a tarball to distribute.
+# If `dirs` specified, directly create the tarball on those directories.
+# Otherwise, assume that `branch` is specified and use git to create the tarball from that branch.  
+
 @task
-def tar_from_git(branch, dirs=None, baseDir='.'):
-    
+def create_tarball(branch=None, dirs=None, baseDir='.'):  
     with lcd(baseDir):
-        local("pwd")
         if dirs:
             local('tar -czf %s.tar.gz %s' % (TAR_NAME, dirs))
 
@@ -418,6 +420,15 @@ def tar_from_git(branch, dirs=None, baseDir='.'):
     if baseDir != '.':
         local('mv %s/%s.tar.gz .' % (baseDir, TAR_NAME))
 
+# legacy synonym for create_tarball, though with `branch` argument required.
+# this is the historical pattern, so `branch` is no longer required in the replacement `create_tarball` task
+
+@task
+def tar_from_git(branch, dirs=None, baseDir='.'):  
+    create_tarball(branch,dirs,baseDir)
+
+
+
 @task
 def clean_up():
     local('git reset --hard ${GIT_COMMIT}')
@@ -518,7 +529,7 @@ def codeversioner():
 # commited), then creates the tarball, finally deploys one at a time
 @task
 def deploycode(branch, nltkLoad="False", doCollectStatic="True", djangoAdmin="True", yarn="False", immutable="True", numKeep="5"):
-    tar_from_git(branch)
+    create_tarball(branch)
     remote_inflate_code(numKeep)
 
     if not yarn in TRUTH_VALUES:
